"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.transformEmitterFilter = exports.run = void 0;
const config_1 = require("../config");
const logHelper_1 = require("../helpers/logHelper");
const providers_1 = require("../utils/providers");
const spyEventSource_1 = require("./spyEventSource");
const wormholeSdk = require("@certusone/wormhole-sdk");
const missedVaaFetching_1 = require("./missedVaaFetching");
let _logger;
const logger = () => {
    if (!_logger) {
        _logger = (0, logHelper_1.getScopedLogger)(["listenerHarness"]);
    }
    return _logger;
};
async function run(plugins, storage) {
    const commonEnv = (0, config_1.getCommonEnv)();
    const providers = (0, providers_1.providersFromChainConfig)(commonEnv.supportedChains);
    if (shouldSpy(plugins)) {
        logger().info("Initializing spy listener...");
        (0, spyEventSource_1.createSpyEventSource)(plugins, storage, providers);
        (0, missedVaaFetching_1.nextVaaFetchingWorker)(plugins, storage, providers);
    }
    if (shouldRest(plugins)) {
        logger().warn(`Rest listener interface not yet implemented`);
        //const restListener = setupRestListener(restFilters);
    }
    logger().debug("End of listener harness run function");
}
exports.run = run;
function shouldRest(plugins) {
    return plugins.some(x => x.shouldRest);
}
function shouldSpy(plugins) {
    return plugins.some(x => x.shouldSpy);
}
async function transformEmitterFilter(x) {
    return {
        chainId: x.chainId,
        emitterAddress: await encodeEmitterAddress(x.chainId, x.emitterAddress),
    };
}
exports.transformEmitterFilter = transformEmitterFilter;
async function encodeEmitterAddress(myChainId, emitterAddressStr) {
    if (myChainId === wormholeSdk.CHAIN_ID_SOLANA ||
        myChainId === wormholeSdk.CHAIN_ID_PYTHNET) {
        return await wormholeSdk.getEmitterAddressSolana(emitterAddressStr);
    }
    if (wormholeSdk.isTerraChain(myChainId)) {
        return await wormholeSdk.getEmitterAddressTerra(emitterAddressStr);
    }
    if (wormholeSdk.isEVMChain(myChainId)) {
        return wormholeSdk.getEmitterAddressEth(emitterAddressStr);
    }
    throw new Error(`Unrecognized wormhole chainId ${myChainId}`);
}
//# sourceMappingURL=listenerHarness.js.map