import { Plugin, StagingAreaKeyLock, Workflow, WorkflowId, WorkflowOptions } from "relayer-plugin-interface";
import { Logger } from "winston";
import { EmitterRecord, EmitterRecordWithKey, WorkflowWithPlugin } from ".";
import { RedisWrapper } from "./redisStore";
import { ChainId } from "@certusone/wormhole-sdk";
import { CommonEnv } from "../config";
export declare function createStorage(plugins: Plugin[], config: CommonEnv, nodeId: string, logger?: Logger): Promise<Storage>;
export declare class Storage {
    private readonly store;
    private readonly _defaultWorkflowOptions;
    private readonly nodeId;
    private readonly plugins;
    private readonly logger;
    constructor(store: RedisWrapper, plugins: Plugin[], _defaultWorkflowOptions: WorkflowOptions, nodeId: string, logger: Logger);
    getEmitterRecord(pluginName: string, chainId: ChainId, emitterAddress: string): Promise<EmitterRecord | null>;
    private getEmitterRecordInner;
    setEmitterRecord(pluginName: string, chainId: ChainId, emitterAddress: string, lastSeenSequence: number): Promise<void>;
    getAllEmitterRecords(): Promise<EmitterRecordWithKey[]>;
    emitHeartbeat(): Promise<void>;
    get defaultWorkflowOptions(): WorkflowOptions;
    numActiveWorkflows(): Promise<number>;
    numEnqueuedWorkflows(): Promise<number>;
    numDelayedWorkflows(): Promise<number>;
    private serializeWorkflow;
    addWorkflow(workflow: Workflow): Promise<void>;
    requeueWorkflow(workflow: Workflow, reExecuteAt: Date): Promise<void>;
    completeWorkflow(workflow: {
        id: WorkflowId;
        pluginName: string;
    }): Promise<void>;
    failWorkflow(workflow: {
        id: WorkflowId;
        pluginName: string;
    }): Promise<void>;
    getWorkflow(workflowId: {
        pluginName: string;
        id: string;
    }): Promise<WorkflowWithPlugin | null>;
    getNextWorkflow(timeoutInSeconds: number): Promise<WorkflowWithPlugin | null>;
    private rawObjToWorkflow;
    getStagingAreaKeyLock(pluginName: string): StagingAreaKeyLock;
    private acquireUnsafeLock;
    private releaseUnsafeLock;
    moveDelayedWorkflowsToReadyQueue(): Promise<number>;
    cleanupStaleActiveWorkflows(): Promise<number>;
}
