"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.assertChainId = exports.assertEvmChainId = exports.wormholeBytesToHex = exports.parseVaaWithBytes = exports.assertBool = exports.sleep = exports.assertArray = exports.assertInt = exports.assertStr = exports.nnull = exports.EngineError = exports.hour = exports.minute = exports.second = void 0;
const wormhole_sdk_1 = require("@certusone/wormhole-sdk");
const ethers_1 = require("ethers");
exports.second = 1000;
exports.minute = 60 * exports.second;
exports.hour = 60 * exports.minute;
class EngineError extends Error {
    args;
    constructor(msg, args) {
        super(msg);
        this.args = args;
    }
}
exports.EngineError = EngineError;
function nnull(x, errMsg) {
    if (x === undefined || x === null) {
        throw new Error("Found unexpected undefined or null. " + errMsg);
    }
    return x;
}
exports.nnull = nnull;
function assertStr(x, fieldName) {
    if (typeof x !== "string") {
        throw new EngineError(`Expected field to be integer, found ${x}`, {
            fieldName,
        });
    }
    return x;
}
exports.assertStr = assertStr;
function assertInt(x, fieldName) {
    if (!Number.isInteger(Number(x))) {
        throw new EngineError(`Expected field to be integer, found ${x}`, {
            fieldName,
        });
    }
    return x;
}
exports.assertInt = assertInt;
function assertArray(x, name, elemsPred) {
    if (!Array.isArray(x) || (elemsPred && !x.every(elemsPred))) {
        throw new EngineError(`Expected value to be array, found ${x}`, {
            name,
        });
    }
    return x;
}
exports.assertArray = assertArray;
function sleep(ms) {
    return new Promise((resolve, reject) => setTimeout(resolve, ms));
}
exports.sleep = sleep;
function assertBool(x, fieldName) {
    if (x !== false && x !== true) {
        throw new EngineError(`Expected field to be boolean, found ${x}`, {
            fieldName,
        });
    }
    return x;
}
exports.assertBool = assertBool;
function parseVaaWithBytes(vaa) {
    // @ts-ignore
    if (vaa?.emitterAddress?.length > 0) {
        return vaa;
    }
    const parsedVaa = (0, wormhole_sdk_1.parseVaa)(vaa);
    parsedVaa.bytes = Buffer.from(vaa);
    return parsedVaa;
}
exports.parseVaaWithBytes = parseVaaWithBytes;
function wormholeBytesToHex(address) {
    return ethers_1.ethers.utils.hexlify(address).replace("0x", "");
}
exports.wormholeBytesToHex = wormholeBytesToHex;
function assertEvmChainId(chainId) {
    if (!(0, wormhole_sdk_1.isEVMChain)(chainId)) {
        throw new EngineError("Expected number to be valid EVM chainId", {
            chainId,
        });
    }
    return chainId;
}
exports.assertEvmChainId = assertEvmChainId;
function assertChainId(chainId) {
    if (!(0, wormhole_sdk_1.isChain)(chainId)) {
        throw new EngineError("Expected number to be valid chainId", { chainId });
    }
    return chainId;
}
exports.assertChainId = assertChainId;
//# sourceMappingURL=utils.js.map